#!/usr/bin/env bash
#
# Executes given cms multiple times until it is successful
#
# Usage:
#
#   ./retry_cmd_until_success.sh [retries] [sleep] [cmd]
#
# Example:
#
#   ./retry_cmd_until_success.sh 10 20 ping ix.de

retries=$1
if [[ ! $retries =~ ^-?[0-9]+$ ]]
then
  echo "Please specify retries count."
  exit 1
fi

shift
sleep_secs=$1
if [[ ! $sleep_secs =~ ^-?[0-9]+$ ]]
then
  echo "Please specify sleep interval in seconds."
  exit 1
fi

shift
cmd=$*
if [[ -z "$cmd" ]]
then
  echo "Please specify a cmd."
  exit 1
fi
echo "Retrying \"$cmd\" ${retries} times."

i=0
until eval $cmd
do
  echo -e "return code: $?\n"
  if [[ $i -ge $retries ]]
  then
    exit 1
  fi
  (( i++ ))
  sleep $sleep_secs
  echo "${i}. retry:"
done
